<?php
/**
 * D4D MARTINA FUCHS admin functions.
 *
 * @package D4D Martina Fuchs
 */

/**
 * Show in WP Dashboard notice about the plugin is not activated.
 *
 * @return void
 */
function d4d_martinaf_fail_load_admin_notice() {
	// Leave to Elementor Pro to manage this.
	if ( function_exists( 'elementor_pro_load_plugin' ) ) {
		return;
	}

	$screen = get_current_screen();
	if ( isset( $screen->parent_file ) && 'plugins.php' === $screen->parent_file && 'update' === $screen->id ) {
		return;
	}

	if ( 'true' === get_user_meta( get_current_user_id(), '_d4d_martinaf_install_notice', true ) ) {
		return;
	}

	$plugin = 'elementor/elementor.php';

	$installed_plugins = get_plugins();

	$is_elementor_installed = isset( $installed_plugins[ $plugin ] );

	if ( $is_elementor_installed ) {
		if ( ! current_user_can( 'activate_plugins' ) ) {
			return;
		}

		$message = __( 'Martina Fuchs theme is a lightweight starter theme designed to work perfectly with D4D Visual Page Builder plugin.', 'd4d-martina-fuchs' );

		$button_text = __( 'Activate Elementor', 'd4d-martina-fuchs' );
		$button_link = wp_nonce_url( 'plugins.php?action=activate&amp;plugin=' . $plugin . '&amp;plugin_status=all&amp;paged=1&amp;s', 'activate-plugin_' . $plugin );
	} else {
		if ( ! current_user_can( 'install_plugins' ) ) {
			return;
		}

		$message = __( 'D4D Martina Fuchs is a lightweight starter theme. We recommend you use it together with D4D Visual Page Builder plugin, they work perfectly together!', 'd4d-martina-fuchs' );

		$button_text = __( 'Install Elementor', 'd4d-martina-fuchs' );
		$button_link = wp_nonce_url( self_admin_url( 'update.php?action=install-plugin&plugin=elementor' ), 'install-plugin_elementor' );
	}

	?>
	<style>
		.notice.d4d-martinaf-notice {
			border-left-color: #9b0a46 !important;
			padding: 20px;
		}
		.rtl .notice.d4d-martinaf-notice {
			border-right-color: #9b0a46 !important;
		}
		.notice.d4d-martinaf-notice .d4d-martinaf-notice-inner {
			display: table;
			width: 100%;
		}
		.notice.d4d-martinaf-notice .d4d-martinaf-notice-inner .d4d-martinaf-notice-icon,
		.notice.d4d-martinaf-notice .d4d-martinaf-notice-inner .d4d-martinaf-notice-content,
		.notice.d4d-martinaf-notice .d4d-martinaf-notice-inner .d4d-martinaf-install-now {
			display: table-cell;
			vertical-align: middle;
		}
		.notice.d4d-martinaf-notice .d4d-martinaf-notice-icon {
			color: #9b0a46;
			font-size: 50px;
			width: 50px;
		}
		.notice.d4d-martinaf-notice .d4d-martinaf-notice-content {
			padding: 0 20px;
		}
		.notice.d4d-martinaf-notice p {
			padding: 0;
			margin: 0;
		}
		.notice.d4d-martinaf-notice h3 {
			margin: 0 0 5px;
		}
		.notice.d4d-martinaf-notice .d4d-martinaf-install-now {
			text-align: center;
		}
		.notice.d4d-martinaf-notice .d4d-martinaf-install-now .d4d-martinaf-install-button {
			padding: 5px 30px;
			height: auto;
			line-height: 20px;
			text-transform: capitalize;
		}
		.notice.d4d-martinaf-notice .d4d-martinaf-install-now .d4d-martinaf-install-button i {
			padding-right: 5px;
		}
		.rtl .notice.d4d-martinaf-notice .d4d-martinaf-install-now .d4d-martinaf-install-button i {
			padding-right: 0;
			padding-left: 5px;
		}
		.notice.d4d-martinaf-notice .d4d-martinaf-install-now .d4d-martinaf-install-button:active {
			transform: translateY(1px);
		}
		@media (max-width: 767px) {
			.notice.d4d-martinaf-notice {
				padding: 10px;
			}
			.notice.d4d-martinaf-notice .d4d-martinaf-notice-inner {
				display: block;
			}
			.notice.d4d-martinaf-notice .d4d-martinaf-notice-inner .d4d-martinaf-notice-content {
				display: block;
				padding: 0;
			}
			.notice.d4d-martinaf-notice .d4d-martinaf-notice-inner .d4d-martinaf-notice-icon,
			.notice.d4d-martinaf-notice .d4d-martinaf-notice-inner .d4d-martinaf-install-now {
				display: none;
			}
		}
	</style>
	<script>jQuery( function( $ ) {
			$( 'div.notice.d4d-martinaf-install-elementor' ).on( 'click', 'button.notice-dismiss', function( event ) {
				event.preventDefault();

				$.post( ajaxurl, {
					action: 'd4d_martinaf_set_admin_notice_viewed'
				} );
			} );
		} );</script>
	<div class="notice updated is-dismissible d4d-martinaf-notice d4d-martinaf-install-elementor">
		<div class="d4d-martinaf-notice-inner">
			<div class="d4d-martinaf-notice-icon">
				<img src="<?php echo esc_url( get_template_directory_uri() . '/assets/images/elementor-logo.png' ); ?>" alt="Elementor Logo" />
			</div>

			<div class="d4d-martinaf-notice-content">
				<h3><?php esc_html_e( 'Thanks for installing Martina Fuchs Theme!', 'd4d-martina-fuchs' ); ?></h3>
				<p>
					<p><?php echo esc_html( $message ); ?></p>
					<a href="#" target="_blank"><?php esc_html_e( 'Learn more about Elementor', 'd4d-martina-fuchs' ); ?></a>
				</p>
			</div>

			<div class="d4d-martinaf-install-now">
				<a class="button button-primary d4d-martinaf-install-button" href="<?php echo esc_attr( $button_link ); ?>"><i class="dashicons dashicons-download"></i><?php echo esc_html( $button_text ); ?></a>
			</div>
		</div>
	</div>
	<?php
}

/**
 * Set Admin Notice Viewed.
 *
 * @return void
 */
function ajax_d4d_martinaf_set_admin_notice_viewed() {
	update_user_meta( get_current_user_id(), '_d4d_martinaf_install_notice', 'true' );
	die;
}

add_action( 'wp_ajax_d4d_martinaf_set_admin_notice_viewed', 'ajax_d4d_martinaf_set_admin_notice_viewed' );

if ( ! did_action( 'elementor/loaded' ) ) {
	add_action( 'admin_notices', 'd4d_martinaf_fail_load_admin_notice' );
}
